@@ -71,9 +71,9 @@ def parse_args():
     parser.add_argument(
         "--show-config",
         action="store_true",
-        help="print actual configration in json format and exit. This is "
+        help="print actual configuration in json format and exit. This is "
              "useful for debugging configuration issues, or reading imageio "
-             "configuraion by other programs.")
+             "configuration by other programs.")
     return parser.parse_args()
 
 
@@ -106,7 +106,7 @@ class Server:
     def __init__(self, config):
         self.config = config
         self.running = False
-        self.auth = auth.Authorizer()
+        self.auth = auth.Authorizer(config)
         self.remote_service = services.RemoteService(self.config, self.auth)
         self.local_service = None
         if config.local.enable:
